@@ -11,9 +11,5 @@ class SparkUtils:
         spark.sparkContext._jsc.hadoopConfiguration().set(
             "mapreduce.fileoutputcommitter.cleanup-failures.ignored", "true"
         )
-        spark.sparkContext._jsc.hadoopConfiguration().set(
-            "mapreduce.fileoutputcommitter.cleanup.skipped", "true"
-        )
-        spark.sparkContext._jsc.hadoopConfiguration().set(
-            "mapreduce.fileoutputcommitter.algorithm.version", "2"
-        )
+        spark.sparkContext._jsc.hadoopConfiguration().set("mapreduce.fileoutputcommitter.cleanup.skipped", "true")
+        spark.sparkContext._jsc.hadoopConfiguration().set("mapreduce.fileoutputcommitter.algorithm.version", "2")
