@@ -1,12 +1,6 @@
-import warnings
-
 import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
 import ai.h2o.featurestore.api.v1.FeatureSetSearch_pb2 as pb_search
-from ai.h2o.featurestore.api.v1.FeatureSetSearch_pb2 import (
-    BooleanFilter,
-    NumericalFilter,
-    TextualFilter,
-)
+from ai.h2o.featurestore.api.v1.FeatureSetSearch_pb2 import BooleanFilter, NumericalFilter, TextualFilter
 
 from .commons.spark_utils import SparkUtils
 
@@ -20,23 +14,13 @@ class DeltaTableFilter:
 
     def __build(self):
         if isinstance(self.value, str):
-            return pb_search.Filter(
-                text=TextualFilter(
-                    field=self.column, operator=self.operator, value=[self.value]
-                )
-            )
+            return pb_search.Filter(text=TextualFilter(field=self.column, operator=self.operator, value=[self.value]))
         elif isinstance(self.value, (int, float)):
             return pb_search.Filter(
-                numeric=NumericalFilter(
-                    field=self.column, operator=self.operator, value=self.value
-                )
+                numeric=NumericalFilter(field=self.column, operator=self.operator, value=self.value)
             )
         elif isinstance(self.value, bool):
-            return pb_search.Filter(
-                boolean=BooleanFilter(
-                    field=self.column, operator=self.operator, value=self.value
-                )
-            )
+            return pb_search.Filter(boolean=BooleanFilter(field=self.column, operator=self.operator, value=self.value))
 
 
 class SparkDataFrame:
@@ -59,18 +43,14 @@ class SparkDataFrame:
         for k, v in write_info.options.items():
             spark.conf.set(k, v)
             if k.startswith("spark.hadoop."):
-                spark.sparkContext._jsc.hadoopConfiguration().set(
-                    k.replace("spark.hadoop.", ""), v
-                )
+                spark.sparkContext._jsc.hadoopConfiguration().set(k.replace("spark.hadoop.", ""), v)
         spark.conf.set("spark.sql.session.timeZone", "UTC")
         self.dataframe.write.parquet(write_info.path)
         self._write_path = write_info.path
 
     def _get_cache_location(self):
         if not self._write_path:
-            raise Exception(
-                "Write the spark frame into the cache before calling get method"
-            )
+            raise Exception("Write the spark frame into the cache before calling get method")
         parquet = pb.TempParquetFileSpec()
         parquet.path = self._write_path
         raw_data_location = pb.RawDataLocation()
@@ -98,14 +78,14 @@ class ParquetFile:
 class Proxy:
     def __init__(self, host="", port=0, user="", password=""):
         if port and not host:
-            raise ValueError(f"Proxy port specified but host is missing!")
+            raise ValueError("Proxy port specified but host is missing!")
         if not port and host:
-            raise ValueError(f"Proxy host specified but port is missing!")
+            raise ValueError("Proxy host specified but port is missing!")
         if port and host:
             if user and not password:
-                raise ValueError(f"Proxy user specified but password is missing!")
+                raise ValueError("Proxy user specified but password is missing!")
             if not user and password:
-                raise ValueError(f"Proxy password specified but user is missing!")
+                raise ValueError("Proxy password specified but user is missing!")
         self.host = host
         self.port = port
         self.user = user
@@ -127,9 +107,9 @@ class SnowflakeTable:
         account="",
     ):
         if not (query or table):
-            raise ValueError(f"table or query is required!")
+            raise ValueError("table or query is required!")
         if query and table:
-            raise ValueError(f"Only one of table or query is supported!")
+            raise ValueError("Only one of table or query is supported!")
 
         self.table = table
         self.database = database
@@ -201,16 +181,16 @@ class SnowflakeCursor:
         self.account = account
 
     def get_latest_query(self):
-        query = "SELECT QUERY_TEXT::VARCHAR FROM TABLE(INFORMATION_SCHEMA.QUERY_HISTORY_BY_SESSION(RESULT_LIMIT => 10)) WHERE QUERY_ID=%s"
-        self.cursor.execute(
-            query, (self.cursor.sfqid,)
-        )  # get the last executed query using the query id
+        query = (
+            "SELECT QUERY_TEXT::VARCHAR "
+            "FROM TABLE(INFORMATION_SCHEMA.QUERY_HISTORY_BY_SESSION(RESULT_LIMIT => 10)) "
+            "WHERE QUERY_ID=%s"
+        )
+        self.cursor.execute(query, (self.cursor.sfqid,))  # get the last executed query using the query id
         try:
             latest_query = self.cursor.fetchone()[0]
             if not latest_query.lower().startswith("select "):
-                raise ValueError(
-                    "Only select queries are supported for registering featuring sets"
-                )
+                raise ValueError("Only select queries are supported for registering featuring sets")
         except IndexError:
             raise ValueError("No query seems to have been executed in this session")
         return latest_query
@@ -227,57 +207,23 @@ class DeltaTable:
 
 
 class CSVFolder:
-    def __init__(
-        self, root_folder, partition_pattern="", delimiter=",", filter_pattern=""
-    ):
-        if partition_pattern:
-            warnings.warn(
-                "partition_pattern is deprecated. Use filter_pattern instead",
-                DeprecationWarning,
-            )
-        if partition_pattern and filter_pattern:
-            raise ValueError(
-                "partition_pattern and filter_pattern cannot be passed at the same time."
-            )
+    def __init__(self, root_folder, delimiter=",", filter_pattern=""):
         self.root_folder = root_folder
-        self.partition_pattern = partition_pattern
-        self.filter_pattern = filter_pattern if filter_pattern else partition_pattern
+        self.filter_pattern = filter_pattern
         self.delimiter = delimiter
 
 
 class ParquetFolder:
-    def __init__(self, root_folder, partition_pattern="", filter_pattern=""):
-        if partition_pattern:
-            warnings.warn(
-                "partition_pattern is deprecated. Use filter_pattern instead",
-                DeprecationWarning,
-            )
-        if partition_pattern and filter_pattern:
-            raise ValueError(
-                "partition_pattern and filter_pattern cannot be passed at the same time."
-            )
+    def __init__(self, root_folder, filter_pattern=""):
         self.root_folder = root_folder
-        self.partition_pattern = partition_pattern
-        self.filter_pattern = filter_pattern if filter_pattern else partition_pattern
+        self.filter_pattern = filter_pattern
 
 
 class JSONFolder:
-    def __init__(
-        self, root_folder, partition_pattern="", multiline=False, filter_pattern=""
-    ):
-        if partition_pattern:
-            warnings.warn(
-                "partition_pattern is deprecated. Use filter_pattern instead",
-                DeprecationWarning,
-            )
-        if partition_pattern and filter_pattern:
-            raise ValueError(
-                "partition_pattern and filter_pattern cannot be passed at the same time."
-            )
+    def __init__(self, root_folder, multiline=False, filter_pattern=""):
         self.root_folder = root_folder
         self.multiline = multiline
-        self.partition_pattern = partition_pattern
-        self.filter_pattern = filter_pattern if filter_pattern else partition_pattern
+        self.filter_pattern = filter_pattern
 
 
 def get_raw_data_location(source):
