@@ -3,12 +3,13 @@ from abc import ABC, abstractmethod
 from concurrent.futures import ThreadPoolExecutor
 
 import ai.h2o.featurestore.api.v1.CoreService_pb2 as pb
+from ai.h2o.featurestore.api.v1.CoreService_pb2_grpc import CoreServiceStub
 
 from ..job_info import JobInfo
 
 
 class BaseJob(ABC):
-    def __init__(self, stub, job_id):
+    def __init__(self, stub: CoreServiceStub, job_id):
         self._stub = stub
         self._job_id = job_id
         self._result = None
@@ -34,14 +35,14 @@ class BaseJob(ABC):
 
     @abstractmethod
     def _response_method(self, job_id):
-        raise NotImplementedError(
-            "Method `_response_method` needs to be implemented by the child class"
-        )
+        raise NotImplementedError("Method `_response_method` needs to be implemented by the child class")
 
     def is_done(self) -> bool:
+        """Job status (whether completed or not)."""
         return self._stub.GetJob(self._job_id).done
 
     def wait_for_result(self):
+        """Return job results after completion."""
         while not self.is_done():
             self.show_progress()
             time.sleep(2)
@@ -49,6 +50,7 @@ class BaseJob(ABC):
         return self.get_result()
 
     def get_result(self):
+        """A job results."""
         if not self._result:
             if not self.is_done():
                 raise Exception("Job has not finished yet!")
@@ -56,9 +58,11 @@ class BaseJob(ABC):
         return self._result
 
     def show_progress(self):
+        """Retrieve job progress."""
         self._info.show_progress()
 
     def get_metrics(self):
+        """Completed metrics of a job."""
         return self._info.get_metrics()
 
     def __repr__(self):
