@@ -9,10 +9,7 @@ class ExtractSchemaJob(BaseJob):
         derivation = None
         if response.derived_from.HasField("transformation"):
             derivation = SchemaDerivation(
-                [
-                    VersionedId(f.id, f.major_version)
-                    for f in response.derived_from.feature_set_ids
-                ],
+                [VersionedId(f.id, f.major_version) for f in response.derived_from.feature_set_ids],
                 Transformation.from_proto(response.derived_from.transformation),
             )
         return Schema(
@@ -27,9 +24,7 @@ class ExtractSchemaJob(BaseJob):
             FeatureSchema(
                 feature_schema.name,
                 feature_schema.data_type,
-                nested_features_schema=ExtractSchemaJob._features_schema_from_proto(
-                    feature_schema.nested
-                ),
+                nested_features_schema=ExtractSchemaJob._features_schema_from_proto(feature_schema.nested),
             )
             for feature_schema in schema
         ]
