@@ -9,6 +9,14 @@ class PersonalAccessToken:
         self._stub = stub
 
     def revoke(self):
+        """Revoke a personal access token.
+
+        A particular token object can be revoked.
+
+        Typical example:
+            token = client.auth.pats.get(token_id)
+            token.revoke()
+        """
         request = pb.TokenRequest()
         request.token_id = self._pat.id
         self._stub.RevokeToken(request)
@@ -39,3 +47,10 @@ class PersonalAccessToken:
 
     def __repr__(self):
         return Utils.pretty_print_proto(self._pat)
+
+    def __str__(self):
+        return (
+            f"Name          : {self.name} \n"
+            f"Description   : {self.description} \n"
+            f"Creation time : {self.creation_time} \n"
+        )
