@@ -20,3 +20,14 @@ class Recommendation:
                 "joins": self._joins,
             }
         )
+
+    def __str__(self):
+        return (
+            f"Source                  \n"
+            f"  Project name        : {self._source.project}\n"
+            f"  Feature set name    : {self._source.feature_set_name}\n"
+            f"Target                  \n"
+            f"  Project name        : {self._target.project}\n"
+            f"  Feature set name    : {self._target.feature_set_name}\n"
+            f"Joins                 : {self._joins}\n"
+        )
