@@ -19,3 +19,6 @@ class User:
 
     def __repr__(self):
         return Utils.pretty_print_proto(self._user)
+
+    def __str__(self):
+        return f"Name          : {self.name} \n" f"Email         : {self.email} \n"
