@@ -1,4 +1,5 @@
 import collections
+import logging
 import time
 from datetime import timedelta
 from functools import wraps
@@ -6,14 +7,12 @@ from functools import wraps
 from featurestore.core.config import ConfigUtils
 
 METRICS_START_TIME = time.time()
-Metrics = collections.namedtuple(
-    "Metrics", "func_name sum_time num_calls min_time max_time avg_time"
-)
+Metrics = collections.namedtuple("Metrics", "func_name sum_time num_calls min_time max_time avg_time")
 
 
 def log(message):
     if ConfigUtils.is_interactive_print_enabled():
-        print(message)
+        logging.info(message)
 
 
 def record_stats(fn):
@@ -23,7 +22,7 @@ def record_stats(fn):
         ret = fn(*args, **kwargs)
         end = time.time()
         delta = timedelta(seconds=end - start).total_seconds()
-        print("\n\nTime taken - %3f seconds" % delta)
+        logging.info(f"\n\nTime taken - {delta:.3f} seconds")
         return ret
 
     return with_perf
