@@ -7,3 +7,5 @@ REVERT_INGEST = pb.JobType.Revert
 MATERIALIZATION_ONLINE = pb.JobType.MaterializationOnline
 COMPUTE_STATISTICS = pb.JobType.ComputeStatistics
 COMPUTE_RECOMMENDATION_CLASSIFIERS = pb.JobType.ComputeRecommendationClassifiers
+CREATE_ML_DATASET = pb.JobType.CreateMLDataset
+BACKFILL = pb.JobType.Backfill
