@@ -1,5 +1,5 @@
 import re
-from typing import List, Tuple
+from typing import List
 
 from ai.h2o.featurestore.api.v1 import CoreService_pb2 as pb
 from ai.h2o.featurestore.api.v1 import FeatureSetProtoApi_pb2 as FeatureSetApi
@@ -8,9 +8,7 @@ from .transformations import Transformation
 
 
 class FeatureSchemaSpecialData:
-    def __init__(
-        self, spi=False, pci=False, rpi=False, demographic=False, sensitive=False
-    ):
+    def __init__(self, spi=False, pci=False, rpi=False, demographic=False, sensitive=False):
         self.spi = spi
         self.pci = pci
         self.rpi = rpi
@@ -18,7 +16,10 @@ class FeatureSchemaSpecialData:
         self.sensitive = sensitive
 
     def __repr__(self):
-        return f"spi={self.spi}, pci={self.pci}, rpi={self.rpi}, demographic={self.demographic}, sensitive={self.sensitive}"
+        return (
+            f"spi={self.spi}, pci={self.pci}, rpi={self.rpi}, demographic={self.demographic}, "
+            f"sensitive={self.sensitive}"
+        )
 
 
 class FeatureSchema:
@@ -30,18 +31,16 @@ class FeatureSchema:
         nested_features_schema=None,
         _feature_type="AUTOMATIC_DISCOVERY",
         description="",
-        classifier="",
+        classifiers: set = None,
     ):
         self._data_type = _data_type
         self._name = name
         self._special_data = special_data or FeatureSchemaSpecialData()
         self._nested_features_schema = nested_features_schema or []
         self._schema = Schema(self._nested_features_schema, False)
-        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(
-            _feature_type
-        )
+        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(_feature_type)
         self._description = description
-        self._classifier = classifier
+        self._classifiers = classifiers or set()
 
     @property
     def schema(self):
@@ -72,9 +71,7 @@ class FeatureSchema:
 
     @feature_type.setter
     def feature_type(self, value):
-        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(
-            value
-        )
+        self._validated_feature_type = FeatureSchema.get_and_validate_feature_type(value)
 
     @property
     def description(self):
@@ -85,26 +82,19 @@ class FeatureSchema:
         self._description = value
 
     @property
-    def classifier(self):
-        return self._classifier
+    def classifiers(self):
+        return self._classifiers
 
-    @classifier.setter
-    def classifier(self, value):
-        self._classifier = value
-
-    @property
-    def schema(self):
-        return self._schema
+    @classifiers.setter
+    def classifiers(self, value: set):
+        self._classifiers = value
 
     def to_string(self):
         return self.data_type
 
     @staticmethod
     def create_from(feature):
-        nested = [
-            FeatureSchema.create_from(nested_feature)
-            for _, nested_feature in feature.nested_features.items()
-        ]
+        nested = [FeatureSchema.create_from(nested_feature) for _, nested_feature in feature.nested_features.items()]
         return FeatureSchema(
             feature.name,
             feature.data_type,
@@ -118,7 +108,7 @@ class FeatureSchema:
             nested,
             feature.profile.feature_type,
             feature.description,
-            feature.classifier,
+            feature.classifiers,
         )
 
     @staticmethod
@@ -127,10 +117,7 @@ class FeatureSchema:
         if feature_type.upper() in valid_values:
             FeatureSetApi.FeatureType.Value(feature_type.upper())
         else:
-            raise Exception(
-                "Invalid feature type. Supported values are: "
-                + ", ".join(map(str, valid_values))
-            )
+            raise Exception("Invalid feature type. Supported values are: " + ", ".join(map(str, valid_values)))
 
     def __repr__(self):
         return self.to_string()
@@ -153,18 +140,13 @@ class SchemaDerivation:
 
     def _to_proto(self):
         return pb.DerivedInformation(
-            feature_set_ids=[
-                pb.VersionedId(id=f.id, major_version=f.major_version)
-                for f in self.feature_set_ids
-            ],
+            feature_set_ids=[pb.VersionedId(id=f.id, major_version=f.major_version) for f in self.feature_set_ids],
             transformation=self.transformation._to_proto(),
         )
 
 
 class Schema:
-    def __init__(
-        self, feature_schemas, is_root_schema, derivation: SchemaDerivation = None
-    ):
+    def __init__(self, feature_schemas, is_root_schema, derivation: SchemaDerivation = None):
         self._feature_schemas = feature_schemas
         self._is_root_schema = is_root_schema
         if is_root_schema:
@@ -178,26 +160,39 @@ class Schema:
         if len(filtered):
             return filtered[0]
         else:
-            raise Exception(
-                f"Feature name '{feature_name}' does not exist in the schema."
-            )
+            raise Exception(f"Feature name '{feature_name}' does not exist in the schema.")
 
     @staticmethod
     def create_from(obj):
+        """Create a schema from String and FeatureSet.
+
+        Args:
+            obj: (str | FeatureSet) Object represents String or FeatureSet.
+
+        Returns:
+            Schema: A schema with feature names and data types.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+
+        Typical example:
+            schema = Schema.create_from("col1 string, col2 string, col3 integer")
+
+        Raises:
+            Exception: Schema can be created either from string or existing feature set.
+
+        For more details:
+            https://docs.h2o.ai/feature-store/latest-stable/docs/api/schema_api.html#create-a-schema-from-a-string
+        """
         from .entities.feature_set import FeatureSet
 
         if isinstance(obj, FeatureSet):
-            features = [
-                FeatureSchema.create_from(feature)
-                for name, feature in obj.features.items()
-            ]
+            features = [FeatureSchema.create_from(feature) for name, feature in obj.features.items()]
             if obj.is_derived():
                 derived_from = obj._feature_set.derived_from
                 derivation = SchemaDerivation(
-                    [
-                        VersionedId(f.id, f.major_version)
-                        for f in derived_from.feature_set_ids
-                    ],
+                    [VersionedId(f.id, f.major_version) for f in derived_from.feature_set_ids],
                     Transformation.from_proto(derived_from.transformation),
                 )
                 return Schema(features, True, derivation)
@@ -206,14 +201,24 @@ class Schema:
         elif isinstance(obj, str):
             return Schema(Schema._parse_features_schema(obj, True)[::-1], True)
         else:
-            raise Exception(
-                "Schema can be created either from string or existing feature set."
-            )
+            raise Exception("Schema can be created either from string or existing feature set.")
 
     @staticmethod
-    def create_derived_from(
-        schema_string: str, derive_from, transformation: Transformation
-    ):
+    def create_derived_from(schema_string: str, derive_from, transformation: Transformation):
+        """Create a schema from a string formatted schema and parent feature set along with transformation.
+
+        Args:
+            schema_string: (str) String contains column names and data types.
+            derive_from: (FeatureSet) Represents a feature set.
+            transformation: (Transformation) Represents an instance of Transformation.
+
+        Returns:
+            Schema: A schema with feature names and data types.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+        """
         return Schema(
             Schema._parse_features_schema(schema_string, True)[::-1],
             True,
@@ -224,20 +229,80 @@ class Schema:
         )
 
     def select(self, feature_names):
-        self._feature_schemas = list(
-            filter(lambda schema: schema.name in feature_names, self._feature_schemas)
-        )
+        """Create a new schema by column selection.
+
+        Args:
+            feature_names: (Iterable[str]) String or iterable collection of strings.
+
+        Returns:
+            Schema: A schema with selected feature names and data types.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+
+        Typical example:
+            schema_str = "id INT, text STRING, label DOUBLE, state STRING, date STRING"
+            schema = Schema.create_from(schema_str)
+            schema.select("id text label")
+
+        For more details:
+            https://docs.h2o.ai/feature-store/latest-stable/docs/api/schema_api.html#create-a-new-schema-by-column-selection
+        """
+        self._feature_schemas = list(filter(lambda schema: schema.name in feature_names, self._feature_schemas))
         return self
 
     def exclude(self, feature_names):
-        self._feature_schemas = list(
-            filter(
-                lambda schema: schema.name not in feature_names, self._feature_schemas
-            )
-        )
+        """Create a new schema by column selection.
+
+        Args:
+            feature_names: (Iterable[str]) String or iterable collection of strings.
+
+        Returns:
+            Schema: A schema with feature names and data types without excluded names.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+
+        Typical example:
+            schema_str = "id INT, text STRING, label DOUBLE, state STRING, date STRING"
+            schema = Schema.create_from(schema_str)
+            schema.exclude("id text label")
+
+        For more details:
+            https://docs.h2o.ai/feature-store/latest-stable/docs/api/schema_api.html#create-a-new-schema-by-column-selection
+        """
+        self._feature_schemas = list(filter(lambda schema: schema.name not in feature_names, self._feature_schemas))
         return self
 
     def append(self, feature_schema, after=None):
+        """Create a new schema.
+
+        A schema is created by adding a new feature schema to the end / after the selected column.
+
+        Args:
+            feature_schema: (FeatureSchema) Represents new feature schema.
+            after: (FeatureSchema) Represents an existing feature schema.
+
+        Returns:
+            Schema: A schema with existing feature names and data types and newly added feature column.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+
+        Typical example:
+            new_feature_schema = FeatureSchema("new_name", STRING)
+            schema.append(new_feature_schema)  # Append to the end
+            schema.append(new_feature_schema, schema["old"])  # Append after old
+
+        Raises:
+            Exception: Feature name does not exist in the schema.
+
+        For more details:
+            https://docs.h2o.ai/feature-store/latest-stable/docs/api/schema_api.html#create-a-new-schema-by-adding-a-new-feature-schema
+        """
         if not after:
             self._feature_schemas.append(feature_schema)
         else:
@@ -246,6 +311,32 @@ class Schema:
         return self
 
     def prepend(self, feature_schema, before=None):
+        """Create a new schema.
+
+        A schema is created by adding a new feature schema to the beginning / before the selected column.
+
+        Args:
+            feature_schema: (FeatureSchema) Represents new feature schema.
+            before: (FeatureSchema) Represents an existing feature schema.
+
+        Returns:
+            Schema: A schema with existing feature names and data types and newly added feature column.
+
+            For example:
+
+            id INT, text STRING, label DOUBLE, state STRING, date TIMESTAMP
+
+        Typical example:
+            new_feature_schema = FeatureSchema("new_name", STRING)
+            schema.prepend(new_feature_schema)  # Prepend to the beginning
+            schema.prepend(new_feature_schema, schema["old"])  # Prepend before old
+
+        Raises:
+            Exception: Feature name does not exist in the schema.
+
+        For more details:
+            https://docs.h2o.ai/feature-store/latest-stable/docs/api/schema_api.html#create-a-new-schema-by-adding-a-new-feature-schema
+        """
         if not before:
             self._feature_schemas.insert(0, feature_schema)
         else:
@@ -254,12 +345,14 @@ class Schema:
         return self
 
     def size(self):
+        """Return the length of a schema."""
         return len(self._feature_schemas)
 
     def is_derived(self):
         return self.derivation is not None
 
     def to_string(self):
+        """Serialize a schema to string format."""
         return ", ".join(
             [
                 f"{feature_schema.name}{self._field_separator}{feature_schema.data_type}"
@@ -282,7 +375,7 @@ class Schema:
                 ),
                 feature_type=feature_schema._validated_feature_type,
                 description=feature_schema.description,
-                classifier=feature_schema.classifier,
+                classifiers=list(feature_schema.classifiers),
             )
             for feature_schema in self._feature_schemas
         ]
@@ -293,12 +386,8 @@ class Schema:
     @staticmethod
     def _parse_features_schema(schema_string, is_root_level):
         if schema_string:
-            feature_schema, remaining_schema_string = Schema._extract_pair(
-                schema_string, is_root_level
-            )
-            return Schema._parse_features_schema(
-                remaining_schema_string, is_root_level
-            ) + [feature_schema]
+            feature_schema, remaining_schema_string = Schema._extract_pair(schema_string, is_root_level)
+            return Schema._parse_features_schema(remaining_schema_string, is_root_level) + [feature_schema]
         else:
             return []
 
@@ -325,38 +414,25 @@ class Schema:
         col_name = splits[0]
         placeholder = None
         if Schema._is_complex(remaining_with_data_type):
-            idx = (
-                Schema._get_index_of_matching_ending_angular_bracket(
-                    remaining_with_data_type
-                )
-                + 1
-            )
+            idx = Schema._get_index_of_matching_ending_angular_bracket(remaining_with_data_type) + 1
             nested_data_type, remaining_schema = (
                 remaining_with_data_type[: idx + 1],
                 remaining_with_data_type[idx + 1 :],
             )
             if remaining_with_data_type.upper().startswith("STRUCT"):
-                nested_features_schema, placeholder = Schema._extract_struct(
-                    nested_data_type
-                )
+                nested_features_schema, placeholder = Schema._extract_struct(nested_data_type)
             else:
-                nested_features_schema, placeholder = Schema._extract_array(
-                    nested_data_type
-                )
+                nested_features_schema, placeholder = Schema._extract_array(nested_data_type)
             if remaining_schema:
                 data_type = placeholder or nested_data_type
-                rest = " ".join(
-                    [split.strip() for split in remaining_schema.split(",")][1:]
-                )
+                rest = " ".join([split.strip() for split in re.split(r",<?![^<]*>>", remaining_schema)])
                 nested_schema = nested_features_schema
             else:
                 data_type = placeholder or nested_data_type
                 rest = ""
                 nested_schema = nested_features_schema
         else:
-            data_type, rest, nested_schema = Schema._extract_primitive(
-                remaining_with_data_type
-            )
+            data_type, rest, nested_schema = Schema._extract_primitive(remaining_with_data_type)
         return (
             FeatureSchema(col_name, data_type, nested_features_schema=nested_schema),
             rest,
@@ -370,18 +446,14 @@ class Schema:
     @staticmethod
     def _extract_first_non_array_data_type(data_type):
         if data_type.upper().startswith("ARRAY"):
-            nested_data_type = re.split(
-                r"\s+<", data_type[len("ARRAY") + 1 : len(data_type) - 1]
-            )[-1].strip()
+            nested_data_type = re.split(r"\s+<", data_type[len("ARRAY") + 1 : len(data_type) - 1])[-1].strip()
             return Schema._extract_first_non_array_data_type(nested_data_type)
         else:
             return data_type
 
     @staticmethod
     def _extract_struct(data_type):
-        nested_data_type = re.split(
-            r"\s+<", data_type[len("STRUCT") + 1 : len(data_type) - 1]
-        )[-1].strip()
+        nested_data_type = re.split(r"\s+<", data_type[len("STRUCT") : len(data_type) - 1].strip("<>"))[-1].strip()
         return (
             Schema._parse_features_schema(nested_data_type, is_root_level=False)[::-1],
             "STRUCT<{0}>",
@@ -389,9 +461,7 @@ class Schema:
 
     @staticmethod
     def _extract_array(data_type):
-        nested_data_type = re.split(
-            r"\s+<", data_type[len("ARRAY") + 1 : len(data_type) - 1]
-        )[-1].strip()
+        nested_data_type = re.split(r"\s+<", data_type[len("ARRAY") + 1 : len(data_type) - 1])[-1].strip()
         if nested_data_type.upper().startswith("ARRAY"):
             return Schema._extract_array(nested_data_type)
         elif nested_data_type.upper().startswith("STRUCT"):
