@@ -19,9 +19,7 @@ class AzurePrincipalCredentials:
 
 
 class S3Credentials:
-    def __init__(
-        self, access_key, secret_key, region=None, endpoint=None, role_arn=None
-    ):
+    def __init__(self, access_key, secret_key, region=None, endpoint=None, role_arn=None):
         self.access_token = access_key
         self.secret_token = secret_key
         self.region = region
